#!/usr/bin/python3
import os
import click

@click.command()
@click.option("--username", prompt="Your Snark Ai username: ", help="Provide your username")
@click.option("--password", prompt="Your Snark Ai password: ", help="Provide your password")
def hello(username, password):
    home = os.path.expanduser("~")
    if not os.path.exists(f"{home}/.snark"):
        os.mkdir(f"{home}/.snark")
    with open(f'{home}/.snark/account', "w") as f:
        f.write(f"username = {username}\n")
        f.write(f"password = {password}\n")


    

# if __name__ == '__main__':
#     hello()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="upload_to_pip_demo_v_4", # Replace with your own username
    version="0.0.4",
    author="Gegham Vardanyan",
    author_email="vardanyan.gegham95@gmail.com",
    description="demo package to test uploading to PyPI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/geghamcode/upload_to_pip_demo.git",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    
    python_requires='>=3.6',
    entry_points={
        "console_scripts": [
            "hub-login = mock_library.click_cmd:hello",
        ],
    },
)